==> libkysdk-applications_2.2.1.0.orig.tar.gz: libkysdk-applications-2.2.1.0/kysdk-qtwidgets/translations/gui_mn.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="mn">
<context>
    <name>kdk::KAboutDialog</name>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="98"/>
        <source>No mail applicaiton accessible in your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="99"/>
        <source>Unable to open mail application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="231"/>
        <location filename="../src/kaboutdialog.cpp" line="245"/>
        <source>Service &amp; Support: </source>
        <translation>ᠦᠢᠯᠡᠴᠢᠯᠡᠬᠦ ᠪᠠ ᠳᠡᠮᠵᠢᠬᠦ ᠪᠦᠯᠬᠦᠮ：</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="237"/>
        <location filename="../src/kaboutdialog.cpp" line="251"/>
        <source>Privacy statement</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kdk::KAboutDialogPrivate</name>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="347"/>
        <source>version :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="352"/>
        <source>Version number not found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kdk::KInputDialog</name>
    <message>
        <location filename="../src/kinputdialog.cpp" line="220"/>
        <source>Enter a value:</source>
        <translation>ᠲᠤᠭ᠎ᠠ ᠬᠡᠮᠵᠢᠭᠳᠡᠯ ᠢ ᠤᠷᠤᠭᠤᠯᠤᠭᠠᠷᠠᠢ：</translation>
    </message>
</context>
<context>
    <name>kdk::KInputDialogPrivate</name>
    <message>
        <location filename="../src/kinputdialog.cpp" line="229"/>
        <source>ok</source>
        <translation>ᠪᠠᠳᠤᠯᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kinputdialog.cpp" line="231"/>
        <source>cancel</source>
        <translation>ᠦᠬᠡᠢᠰᠬᠡᠬᠦ</translation>
    </message>
</context>
<context>
    <name>kdk::KMenuButton</name>
    <message>
        <location filename="../src/kmenubutton.cpp" line="40"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="41"/>
        <source>Setting</source>
        <translation>ᠳᠤᠬᠢᠷᠠᠭᠤᠯᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="42"/>
        <source>Theme</source>
        <translation>ᠭᠤᠤᠯ ᠰᠡᠳᠦᠪ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="43"/>
        <source>Assist</source>
        <translation>ᠳᠤᠰᠠᠯᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="44"/>
        <source>About</source>
        <translation>ᠲᠤᠬᠠᠢ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="45"/>
        <source>Quit</source>
        <translation>ᠪᠤᠴᠠᠵᠤ ᠭᠠᠷᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="52"/>
        <source>Auto</source>
        <translation>ᠭᠤᠤᠯ ᠰᠡᠳᠦᠪ ᠢ ᠳᠠᠭᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="54"/>
        <source>Light</source>
        <translation>ᠬᠦᠶᠦᠬᠡᠨ ᠦᠩᠭᠡ ᠲᠠᠢ ᠭᠤᠤᠯ ᠰᠡᠳᠦᠪ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="56"/>
        <source>Dark</source>
        <translation>ᠬᠦᠨ ᠦᠩᠭᠡ ᠲᠠᠢ ᠭᠤᠤᠯ ᠰᠡᠳᠦᠪ</translation>
    </message>
</context>
<context>
    <name>kdk::KProgressDialog</name>
    <message>
        <location filename="../src/kprogressdialog.cpp" line="48"/>
        <source>cancel</source>
        <translation>ᠦᠬᠡᠢᠰᠬᠡᠬᠦ</translation>
    </message>
</context>
<context>
    <name>kdk::KSearchLineEditPrivate</name>
    <message>
        <location filename="../src/ksearchlineedit.cpp" line="384"/>
        <source>search</source>
        <translation>ᠬᠠᠢᠯᠳᠠ</translation>
    </message>
    <message>
        <location filename="../src/ksearchlineedit.cpp" line="486"/>
        <source>Search</source>
        <translation>ᠬᠠᠢᠯᠳᠠ</translation>
    </message>
</context>
<context>
    <name>kdk::KSecurityLevelBar</name>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="38"/>
        <source>Low</source>
        <translation>ᠳᠤᠤᠷ᠎ᠠ</translation>
    </message>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="41"/>
        <source>Medium</source>
        <translation>ᠳᠤᠮᠳᠠ</translation>
    </message>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="44"/>
        <source>High</source>
        <translation>ᠦᠨᠳᠦᠷ</translation>
    </message>
</context>
<context>
    <name>kdk::KSecurityLevelBarPrivate</name>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="112"/>
        <source>Low</source>
        <translation>ᠳᠤᠤᠷ᠎ᠠ</translation>
    </message>
</context>
<context>
    <name>kdk::KUninstallDialog</name>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="102"/>
        <location filename="../src/kuninstalldialog.cpp" line="194"/>
        <source>uninstall</source>
        <translation>ᠲᠡᠷᠡ ᠳᠠᠷᠤᠢ ᠪᠠᠭᠤᠯᠭᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="163"/>
        <source>deb name:</source>
        <translation>ᠪᠠᠭᠳᠠᠬᠤ ᠨᠡᠷ᠎ᠡ ：</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="168"/>
        <source>deb version:</source>
        <translation>ᠬᠡᠪᠯᠡᠯ：</translation>
    </message>
</context>
<context>
    <name>kdk::KUninstallDialogPrivate</name>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="283"/>
        <source>deb name:</source>
        <translation>ᠪᠠᠭᠳᠠᠬᠤ ᠨᠡᠷ᠎ᠡ：</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="287"/>
        <source>deb version:</source>
        <translation>ᠬᠡᠪᠯᠡᠯ：</translation>
    </message>
</context>
<context>
    <name>kdk::KWindowButtonBarPrivate</name>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="192"/>
        <source>Minimize</source>
        <translation>ᠬᠠᠮᠤᠭ ᠤᠨ ᠪᠠᠭᠠᠴᠢᠯᠠᠯ</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="201"/>
        <source>Close</source>
        <translation>ᠬᠠᠭᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="251"/>
        <source>Maximize</source>
        <translation>ᠬᠠᠮᠤᠭ ᠤᠨ ᠶᠡᠬᠡᠴᠢᠯᠡᠯ</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="256"/>
        <source>Restore</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> libkysdk-applications_2.3.1.0.orig.tar.gz: libkysdk-applications-2.3.1.0/kysdk-qtwidgets/translations/gui_mn.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="mn">
<context>
    <name>kdk::KAboutDialog</name>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="98"/>
        <source>No mail applicaiton accessible in your system.</source>
        <translation>ᠲᠠᠨ ᠤ ᠰᠢᠰᠲ᠋ᠧᠮ ᠳᠦ ᠶᠠᠮᠠᠷ ᠴᠤ ᠡᠯᠧᠺᠲ᠋ᠷᠣᠨ ᠰᠢᠤᠳᠠᠨ ᠤ ᠵᠦᠢᠯ ᠦᠨ ᠬᠡᠷᠡᠭᠯᠡᠯᠲᠡ ᠤᠭᠰᠠᠷᠠᠭᠰᠠᠨ ᠦᠭᠡᠢ ᠃</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="99"/>
        <source>Unable to open mail application</source>
        <translation>ᠰᠢᠤᠳᠠᠨ ᠤ ᠵᠦᠢᠯ ᠦᠨ ᠵᠣᠴᠢᠨ ᠡᠷᠦᠬᠡ ᠶᠢ ᠨᠡᠭᠡᠭᠡᠵᠦ ᠳᠡᠶᠢᠯᠬᠦ ᠦᠭᠡᠢ ᠃</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="231"/>
        <location filename="../src/kaboutdialog.cpp" line="245"/>
        <source>Service &amp; Support: </source>
        <translation>ᠦᠢᠯᠡᠴᠢᠯᠡᠬᠦ ᠪᠠ ᠳᠡᠮᠵᠢᠬᠦ ᠪᠦᠯᠬᠦᠮ：</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="237"/>
        <location filename="../src/kaboutdialog.cpp" line="251"/>
        <source>Privacy statement</source>
        <translation>《ᠨᠢᠭᠤᠴᠠ ᠶᠢᠨ ᠢᠯᠡᠷᠬᠡᠶᠢᠯᠡᠯᠲᠡ》</translation>
    </message>
</context>
<context>
    <name>kdk::KAboutDialogPrivate</name>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="348"/>
        <source>version :</source>
        <translation>ᠬᠡᠪᠯᠡᠯ</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="353"/>
        <source>Version number not found</source>
        <translation>ᠵᠣᠬᠢᠴᠠᠩᠭᠤᠢ ᠬᠡᠪᠯᠡᠯ ᠦᠨ ᠨᠣᠮᠧᠷ ᠢ ᠡᠷᠢᠵᠦ ᠣᠯᠣᠭᠰᠠᠨ ᠦᠭᠡᠢ ᠃</translation>
    </message>
</context>
<context>
    <name>kdk::KInputDialog</name>
    <message>
        <location filename="../src/kinputdialog.cpp" line="220"/>
        <source>Enter a value:</source>
        <translation>ᠲᠤᠭ᠎ᠠ ᠬᠡᠮᠵᠢᠭᠳᠡᠯ ᠢ ᠤᠷᠤᠭᠤᠯᠤᠭᠠᠷᠠᠢ：</translation>
    </message>
</context>
<context>
    <name>kdk::KInputDialogPrivate</name>
    <message>
        <location filename="../src/kinputdialog.cpp" line="229"/>
        <source>ok</source>
        <translation>ᠪᠠᠳᠤᠯᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kinputdialog.cpp" line="231"/>
        <source>cancel</source>
        <translation>ᠦᠬᠡᠢᠰᠬᠡᠬᠦ</translation>
    </message>
</context>
<context>
    <name>kdk::KMenuButton</name>
    <message>
        <location filename="../src/kmenubutton.cpp" line="40"/>
        <source>Options</source>
        <translation>ᠰᠣᠩᠭᠣᠯᠲᠠ ᠃</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="41"/>
        <source>Setting</source>
        <translation>ᠳᠤᠬᠢᠷᠠᠭᠤᠯᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="42"/>
        <source>Theme</source>
        <translation>ᠭᠤᠤᠯ ᠰᠡᠳᠦᠪ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="43"/>
        <source>Assist</source>
        <translation>ᠳᠤᠰᠠᠯᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="44"/>
        <source>About</source>
        <translation>ᠲᠤᠬᠠᠢ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="45"/>
        <source>Quit</source>
        <translation>ᠪᠤᠴᠠᠵᠤ ᠭᠠᠷᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="52"/>
        <source>Auto</source>
        <translation>ᠭᠤᠤᠯ ᠰᠡᠳᠦᠪ ᠢ ᠳᠠᠭᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="54"/>
        <source>Light</source>
        <translation>ᠬᠦᠶᠦᠬᠡᠨ ᠦᠩᠭᠡ ᠲᠠᠢ ᠭᠤᠤᠯ ᠰᠡᠳᠦᠪ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="56"/>
        <source>Dark</source>
        <translation>ᠬᠦᠨ ᠦᠩᠭᠡ ᠲᠠᠢ ᠭᠤᠤᠯ ᠰᠡᠳᠦᠪ</translation>
    </message>
</context>
<context>
    <name>kdk::KProgressDialog</name>
    <message>
        <location filename="../src/kprogressdialog.cpp" line="48"/>
        <source>cancel</source>
        <translation>ᠦᠬᠡᠢᠰᠬᠡᠬᠦ</translation>
    </message>
</context>
<context>
    <name>kdk::KSearchLineEditPrivate</name>
    <message>
        <source>search</source>
        <translation type="vanished">ᠬᠠᠢᠯᠳᠠ</translation>
    </message>
    <message>
        <location filename="../src/ksearchlineedit.cpp" line="384"/>
        <location filename="../src/ksearchlineedit.cpp" line="486"/>
        <source>Search</source>
        <translation>ᠬᠠᠢᠯᠳᠠ</translation>
    </message>
</context>
<context>
    <name>kdk::KSecurityLevelBar</name>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="38"/>
        <source>Low</source>
        <translation>ᠳᠤᠤᠷ᠎ᠠ</translation>
    </message>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="41"/>
        <source>Medium</source>
        <translation>ᠳᠤᠮᠳᠠ</translation>
    </message>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="44"/>
        <source>High</source>
        <translation>ᠦᠨᠳᠦᠷ</translation>
    </message>
</context>
<context>
    <name>kdk::KSecurityLevelBarPrivate</name>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="112"/>
        <source>Low</source>
        <translation>ᠳᠤᠤᠷ᠎ᠠ</translation>
    </message>
</context>
<context>
    <name>kdk::KUninstallDialog</name>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="102"/>
        <location filename="../src/kuninstalldialog.cpp" line="194"/>
        <source>uninstall</source>
        <translation>ᠲᠡᠷᠡ ᠳᠠᠷᠤᠢ ᠪᠠᠭᠤᠯᠭᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="163"/>
        <source>deb name:</source>
        <translation>ᠪᠠᠭᠳᠠᠬᠤ ᠨᠡᠷ᠎ᠡ ：</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="168"/>
        <source>deb version:</source>
        <translation>ᠬᠡᠪᠯᠡᠯ：</translation>
    </message>
</context>
<context>
    <name>kdk::KUninstallDialogPrivate</name>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="283"/>
        <source>deb name:</source>
        <translation>ᠪᠠᠭᠳᠠᠬᠤ ᠨᠡᠷ᠎ᠡ：</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="287"/>
        <source>deb version:</source>
        <translation>ᠬᠡᠪᠯᠡᠯ：</translation>
    </message>
</context>
<context>
    <name>kdk::KWindowButtonBarPrivate</name>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="192"/>
        <source>Minimize</source>
        <translation>ᠬᠠᠮᠤᠭ ᠤᠨ ᠪᠠᠭᠠᠴᠢᠯᠠᠯ</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="201"/>
        <source>Close</source>
        <translation>ᠬᠠᠭᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="251"/>
        <source>Maximize</source>
        <translation>ᠬᠠᠮᠤᠭ ᠤᠨ ᠶᠡᠬᠡᠴᠢᠯᠡᠯ</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="256"/>
        <source>Restore</source>
        <translation>ᠤᠭ ᠢᠶᠠᠨ ᠪᠤᠴᠠᠭᠠᠬᠤ</translation>
    </message>
</context>
</TS>
